==> huaweicloudsdkvpc-3.1.134-py2.py3-none-any.whl: huaweicloudsdkvpc/v2/model/neutron_update_firewall_rule_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NeutronUpdateFirewallRuleResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'firewall_rule': 'NeutronFirewallRule'
    }

    attribute_map = {
        'firewall_rule': 'firewall_rule'
    }

    def __init__(self, firewall_rule=None):
        """NeutronUpdateFirewallRuleResponse

        The model defined in huaweicloud sdk

        :param firewall_rule: 
        :type firewall_rule: :class:`huaweicloudsdkvpc.v2.NeutronFirewallRule`
        """
        
        super(NeutronUpdateFirewallRuleResponse, self).__init__()

        self._firewall_rule = None
        self.discriminator = None

        if firewall_rule is not None:
            self.firewall_rule = firewall_rule

    @property
    def firewall_rule(self):
        """Gets the firewall_rule of this NeutronUpdateFirewallRuleResponse.

        :return: The firewall_rule of this NeutronUpdateFirewallRuleResponse.
        :rtype: :class:`huaweicloudsdkvpc.v2.NeutronFirewallRule`
        """
        return self._firewall_rule

    @firewall_rule.setter
    def firewall_rule(self, firewall_rule):
        """Sets the firewall_rule of this NeutronUpdateFirewallRuleResponse.

        :param firewall_rule: The firewall_rule of this NeutronUpdateFirewallRuleResponse.
        :type firewall_rule: :class:`huaweicloudsdkvpc.v2.NeutronFirewallRule`
        """
        self._firewall_rule = firewall_rule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NeutronUpdateFirewallRuleResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpc-3.1.150-py2.py3-none-any.whl: huaweicloudsdkvpc/v2/model/neutron_update_firewall_rule_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NeutronUpdateFirewallRuleResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'firewall_rule': 'NeutronFirewallRule'
    }

    attribute_map = {
        'firewall_rule': 'firewall_rule'
    }

    def __init__(self, firewall_rule=None):
        r"""NeutronUpdateFirewallRuleResponse

        The model defined in huaweicloud sdk

        :param firewall_rule: 
        :type firewall_rule: :class:`huaweicloudsdkvpc.v2.NeutronFirewallRule`
        """
        
        super(NeutronUpdateFirewallRuleResponse, self).__init__()

        self._firewall_rule = None
        self.discriminator = None

        if firewall_rule is not None:
            self.firewall_rule = firewall_rule

    @property
    def firewall_rule(self):
        r"""Gets the firewall_rule of this NeutronUpdateFirewallRuleResponse.

        :return: The firewall_rule of this NeutronUpdateFirewallRuleResponse.
        :rtype: :class:`huaweicloudsdkvpc.v2.NeutronFirewallRule`
        """
        return self._firewall_rule

    @firewall_rule.setter
    def firewall_rule(self, firewall_rule):
        r"""Sets the firewall_rule of this NeutronUpdateFirewallRuleResponse.

        :param firewall_rule: The firewall_rule of this NeutronUpdateFirewallRuleResponse.
        :type firewall_rule: :class:`huaweicloudsdkvpc.v2.NeutronFirewallRule`
        """
        self._firewall_rule = firewall_rule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NeutronUpdateFirewallRuleResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
